{ config, lib, pkgs, ... }:

let

in {
  imports = [
    ./hardware-configuration.nix
    ./webapps/default.nix
  ];

  users.groups.dotfiles = {};

  normalUsers = {
    reidlab = {
      conf = {
        packages = with pkgs; [ bat tree micro duf ];
        extraGroups = [ "wheel" "dotfiles" ];
        openssh.authorizedKeys.keys = [
          "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAICmwWuwS+a1GzYFSNOkgk/zF5bolXqat1RP5FXJv+vto reidlab@rei-pc"
          "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIKC12NkyZAFNDHfq1ECh4uAgM4mpKfsQnL3XF/ZzSyCJ reidlab@rei-phone"
        ];
      };

      homeConf.home = {
        sessionVariables = {
          EDITOR = "micro";
        };
      };
    };
  };

  keyboard = {
    locale = "en_US.UTF-8";
    variant = "qwerty";
  };

  modules = {
    services = {
      ssh = {
        enable = true;
        requirePassword = false;
      };

      postgres.enable = true;

      redis.enable = true;

      mosh.enable = true;
    };

    security.useDoas = true;
  };

  networking = {
    hostName = "nixos-server-reid";
    networkmanager.enable = true;
  };
}
